==> paragraph_lineage-1.0.0.tar.gz: paragraph_lineage/src/Plugin/Field/FieldFormatter/ParagraphIdLinkFormatter.php <==
<?php

namespace Drupal\paragraph_lineage\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Annotation\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Plugin implementation of the 'paragraph_id_link' formatter.
 *
 * @FieldFormatter(
 *   id = "paragraph_id_link",
 *   label = @Translation("Link to Paragraph"),
 *   field_types = {
 *     "integer"
 *   }
 * )
 */
class ParagraphIdLinkFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    foreach ($items as $delta => $item) {
      if ($item->value) {
        $paragraph = \Drupal::entityTypeManager()->getStorage('paragraph')->load($item->value);
        // Create a link to the custom route using the paragraph ID.
        $url = Url::fromRoute('paragraph_lineage.paragraph.admin_view', ['paragraph' => $item->value]);
        $link_title = $this->t("View lineage for @name", ['@name' => $paragraph->label()]);

        // Render the link.
        $elements[$delta] = [
          '#type' => 'link',
          '#title' => $link_title,
          '#url' => $url,
        ];
      }
    }

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings(): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state): array {
    return [];
  }

}

==> paragraph_lineage-1.0.3.tar.gz: paragraph_lineage/src/Plugin/Field/FieldFormatter/ParagraphIdLinkFormatter.php <==
<?php

namespace Drupal\paragraph_lineage\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Annotation\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Plugin implementation of the 'paragraph_id_link' formatter.
 *
 * @FieldFormatter(
 *   id = "paragraph_id_link",
 *   label = @Translation("Link to Paragraph"),
 *   field_types = {
 *     "integer"
 *   }
 * )
 */
class ParagraphIdLinkFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    foreach ($items as $delta => $item) {
      $entity =  $item->getEntity();
      $route = 'entity.' . $entity->getEntityTypeId() . '.canonical';
      $label = 'View @name';
      if($entity->getEntityTypeId() == 'paragraph') {
        $route = 'entity.paragraph.canonical';
        $label = 'View lineage for @name';
      }
      if ($item->value) {
        // Create a link to the custom route using the paragraph ID.
        $url = Url::fromRoute($route, ['paragraph' => $item->value]);
        $link_title = $this->t($label, ['@name' => $entity->label()]);

        // Render the link.
        $elements[$delta] = [
          '#type' => 'link',
          '#title' => $link_title,
          '#url' => $url,
        ];
      }
    }

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings(): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state): array {
    return [];
  }

}
